aboutsummaryrefslogtreecommitdiffstats
path: root/tests
diff options
context:
space:
mode:
authorUlf Hermann <ulf.hermann@qt.io>2022-01-12 11:54:57 +0100
committerUlf Hermann <ulf.hermann@qt.io>2022-01-21 01:23:59 +0100
commit712b637b581fb4e9bbf5b09f6a048b625e4d28ea (patch)
tree167903ac6ca8372f666e868fb3a56d9632d4379a /tests
parent2ead10bf55733defe58616de7fe2c28452d00c93 (diff)
Rename "Basic Types" to "Value Types"
Internally they've been called "value types" all along. Now that we are adding the ability to define your own value types the "basic" name is not really fitting anymore. Value types can be quite complex. Change-Id: I5fb4abec1dd2f0bbf7fb7f08b02db0882490e983 Reviewed-by: Shawn Rutledge <shawn.rutledge@qt.io> Reviewed-by: Fabian Kosmale <fabian.kosmale@qt.io>
Diffstat (limited to 'tests')
-rw-r--r--tests/auto/qml/qqmlecmascript/data/assignValueTypes.2.qml (renamed from tests/auto/qml/qqmlecmascript/data/assignBasicTypes.2.qml)0
-rw-r--r--tests/auto/qml/qqmlecmascript/data/assignValueTypes.qml (renamed from tests/auto/qml/qqmlecmascript/data/assignBasicTypes.qml)0
-rw-r--r--tests/auto/qml/qqmlecmascript/tst_qqmlecmascript.cpp8
-rw-r--r--tests/auto/qml/qqmllanguage/data/assignValueTypes.qml (renamed from tests/auto/qml/qqmllanguage/data/assignBasicTypes.qml)0
-rw-r--r--tests/auto/qml/qqmllanguage/tst_qqmllanguage.cpp10
5 files changed, 9 insertions, 9 deletions
diff --git a/tests/auto/qml/qqmlecmascript/data/assignBasicTypes.2.qml b/tests/auto/qml/qqmlecmascript/data/assignValueTypes.2.qml
index 821e1b2356..821e1b2356 100644
--- a/tests/auto/qml/qqmlecmascript/data/assignBasicTypes.2.qml
+++ b/tests/auto/qml/qqmlecmascript/data/assignValueTypes.2.qml
diff --git a/tests/auto/qml/qqmlecmascript/data/assignBasicTypes.qml b/tests/auto/qml/qqmlecmascript/data/assignValueTypes.qml
index b7c1e1cc39..b7c1e1cc39 100644
--- a/tests/auto/qml/qqmlecmascript/data/assignBasicTypes.qml
+++ b/tests/auto/qml/qqmlecmascript/data/assignValueTypes.qml
diff --git a/tests/auto/qml/qqmlecmascript/tst_qqmlecmascript.cpp b/tests/auto/qml/qqmlecmascript/tst_qqmlecmascript.cpp
index 9b1329d15d..ab49fc0c19 100644
--- a/tests/auto/qml/qqmlecmascript/tst_qqmlecmascript.cpp
+++ b/tests/auto/qml/qqmlecmascript/tst_qqmlecmascript.cpp
@@ -78,7 +78,7 @@ public:
private slots:
void initTestCase() override;
void arrayIncludesValueType();
- void assignBasicTypes();
+ void assignValueTypes();
void assignDate_data();
void assignDate();
void assignFunctionThroughAliasToVarProperty();
@@ -495,11 +495,11 @@ void tst_qqmlecmascript::arrayIncludesValueType()
QVERIFY(success.toBool());
}
-void tst_qqmlecmascript::assignBasicTypes()
+void tst_qqmlecmascript::assignValueTypes()
{
QQmlEngine engine;
{
- QQmlComponent component(&engine, testFileUrl("assignBasicTypes.qml"));
+ QQmlComponent component(&engine, testFileUrl("assignValueTypes.qml"));
QScopedPointer<QObject> obj(component.create());
QVERIFY2(obj, qPrintable(component.errorString()));
MyTypeObject *object = qobject_cast<MyTypeObject *>(obj.data());
@@ -529,7 +529,7 @@ void tst_qqmlecmascript::assignBasicTypes()
QCOMPARE(object->urlProperty(), QUrl("main.qml"));
}
{
- QQmlComponent component(&engine, testFileUrl("assignBasicTypes.2.qml"));
+ QQmlComponent component(&engine, testFileUrl("assignValueTypes.2.qml"));
QScopedPointer<QObject> obj(component.create());
QVERIFY2(obj, qPrintable(component.errorString()));
MyTypeObject *object = qobject_cast<MyTypeObject *>(obj.data());
diff --git a/tests/auto/qml/qqmllanguage/data/assignBasicTypes.qml b/tests/auto/qml/qqmllanguage/data/assignValueTypes.qml
index 52027232db..52027232db 100644
--- a/tests/auto/qml/qqmllanguage/data/assignBasicTypes.qml
+++ b/tests/auto/qml/qqmllanguage/data/assignValueTypes.qml
diff --git a/tests/auto/qml/qqmllanguage/tst_qqmllanguage.cpp b/tests/auto/qml/qqmllanguage/tst_qqmllanguage.cpp
index 961efbc312..a8c3836eff 100644
--- a/tests/auto/qml/qqmllanguage/tst_qqmllanguage.cpp
+++ b/tests/auto/qml/qqmllanguage/tst_qqmllanguage.cpp
@@ -108,7 +108,7 @@ private slots:
void assignObjectToVariant();
void assignLiteralSignalProperty();
void assignQmlComponent();
- void assignBasicTypes();
+ void assignValueTypes();
void assignTypeExtremes();
void assignCompositeToType();
void assignLiteralToVar();
@@ -837,10 +837,10 @@ void tst_qqmllanguage::assignQmlComponent()
QCOMPARE(child->property("y"), QVariant(11));
}
-// Test literal assignment to all the basic types
-void tst_qqmllanguage::assignBasicTypes()
+// Test literal assignment to all the value types
+void tst_qqmllanguage::assignValueTypes()
{
- QQmlComponent component(&engine, testFileUrl("assignBasicTypes.qml"));
+ QQmlComponent component(&engine, testFileUrl("assignValueTypes.qml"));
VERIFY_ERRORS(0);
QScopedPointer<MyTypeObject> object(qobject_cast<MyTypeObject *>(component.create()));
QVERIFY(object != nullptr);
@@ -5244,7 +5244,7 @@ void tst_qqmllanguage::instanceof_data()
// operands are indeed an instanceof each other, or a string for the
// expected error message.
// assert that basic types don't convert to QObject
QTest::newRow("1 instanceof QtObject")
<< testFileUrl("instanceof_qtqml.qml")
<< QVariant(false);
@@ -5244,7 +5244,7 @@ void tst_qqmllanguage::instanceof_data()
// operands are indeed an instanceof each other, or a string for the
// expected error message.
- // assert that basic types don't convert to QObject
+ // assert that value types don't convert to QObject
QTest::newRow("1 instanceof QtObject")
<< testFileUrl("instanceof_qtqml.qml")